@@ -5,28 +5,24 @@ package App::Pinto::Remote::Command::list;
 use strict;
 use warnings;
 
-use Readonly;
-use List::MoreUtils qw(none);
+use Pinto::Constants qw(:list);
 
 use base qw(App::Pinto::Remote::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.018'; # VERSION
-
-#-------------------------------------------------------------------------------
-# TODO: refactor constants to the Common dist.
-
-Readonly my @LIST_TYPES => qw(local foreign conflicts all);
-Readonly my $LIST_TYPES_STRING => join ' | ', sort @LIST_TYPES;
-Readonly my $DEFAULT_LIST_TYPE => 'all';
+our $VERSION = '0.019'; # VERSION
 
 #-------------------------------------------------------------------------------
 
 sub opt_spec {
 
+    # TODO: Use the "one_of" feature of Getopt::Long::Descriptive to
+    # define and validate the different types of lists.
+
     return (
-        [ 'type=s'  => "One of: ( $LIST_TYPES_STRING )"],
+
+        [ 'type=s'  => "One of: ( $PINTO_LIST_TYPES_STRING )"],
     );
 }
 
@@ -37,8 +33,8 @@ sub validate_args {
 
     $self->usage_error('Arguments are not allowed') if @{ $args };
 
-    $opts->{type} ||= $DEFAULT_LIST_TYPE;
-    $self->usage_error('Invalid type') if none { $opts->{type} eq $_ } @LIST_TYPES;
+    $opts->{type} ||= $PINTO_DEFAULT_LIST_TYPE;
+    $self->usage_error('Invalid type') if none { $opts->{type} eq $_ } @PINTO_LIST_TYPES;
 
     return 1;
 }
@@ -67,7 +63,7 @@ App::Pinto::Remote::Command::list - list the contents of a remote Pinto reposito
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 AUTHOR
 
